# metric


Metrics for evaluating machine learning models or Data Science


Include :
   All metrics from SKLEARN.
   Category based metrics.




Links :

https://www.reddit.com/r/MachineLearning/comments/e8m4zr/open_source_metric_python_package_beta_release/?






